@@ -1,10 +1,8 @@
 from .default import DefaultClient
 from .sharded import ShardClient
 from .herd import HerdClient
-from .dummy import RedisDummyCache
 
 
 __all__ = ["DefaultClient",
            "ShardClient",
-           "HerdClient",
-           "RedisDummyCache"]
+           "HerdClient"]
